==> ddlcli-0.0.1.tar.gz: ddlcli-0.0.1/ddlcli/s3_util.py <==
import boto3
import os
from os import listdir
from os.path import isfile, join, isdir

def create_s3_client(region_name, aws_access_key_id, aws_secret_access_key):
    client = boto3.client(
        's3',
        region_name=region_name,
        aws_access_key_id=aws_access_key_id,
        aws_secret_access_key=aws_secret_access_key)
    return client

def upload_dir_to_s3(dir_path, bucket_name, folder_name, uuid, client):
    s3_folder_name = "{0}/{1}".format(uuid, folder_name)
    assert client is not None

    for f in listdir(dir_path):
        if isfile(join(dir_path, f)):
            print("uploading file {0} to {1}".format(join(dir_path, f), construct_s3_path(bucket_name, s3_folder_name)))
            upload_file_to_s3(join(dir_path, f), bucket_name, s3_folder_name, client)
        elif isdir(join(dir_path, f)):
            print("uploading directory {0} to {1}".format(join(dir_path, f), construct_s3_path(bucket_name, s3_folder_name)))
            s3_dir_name = folder_name + "/" + f
            upload_dir_to_s3(join(dir_path, f), bucket_name, s3_dir_name, uuid, client)

    return s3_folder_name


def upload_file_to_s3(file_path, bucket_name, folder_name, client):
    invalid_extension = [".c", ".cpp", ".js", ".java", ".exe", ".dll", ".o", ".tar", ".gz"]

    if os.path.exists(file_path):
        filename = os.path.basename(file_path)
        name, extension = os.path.splitext(filename)
        if extension not in invalid_extension:
            s3_file_name = "{0}/{1}".format(folder_name, filename)
            print("uploading file {0} to {1}".format(file_path, construct_s3_path(bucket_name, s3_file_name)))
            client.upload_file(file_path, bucket_name, s3_file_name)
            return s3_file_name
    else:
        raise ValueError("file {0} does not exist".format(file_path))

def construct_s3_path(bucket_name, folder_name):
    return "s3://{0}/{1}".format(bucket_name, folder_name)

==> ddlcli-0.0.5.tar.gz: ddlcli-0.0.5/ddlcli/s3_util.py <==
import boto3
import os
from os import listdir
from os.path import isfile, join, isdir

def create_s3_client(s3_temp_token):
    client = boto3.client(
        's3',
        region_name=s3_temp_token["s3_region"],
        aws_access_key_id=s3_temp_token["access_key_id"],
        aws_secret_access_key=s3_temp_token["secret_access_key"],
        aws_session_token=s3_temp_token['session_token'])
    return client

def upload_dir_to_s3(dir_path, bucket_name, folder_name, uuid, client):
    s3_folder_name = "{0}/{1}".format(uuid, folder_name)
    assert client is not None

    for f in listdir(dir_path):
        if isfile(join(dir_path, f)):
            print("uploading file {0} to {1}".format(join(dir_path, f), construct_s3_path(bucket_name, s3_folder_name)))
            upload_file_to_s3(join(dir_path, f), bucket_name, s3_folder_name, client)
        elif isdir(join(dir_path, f)):
            print("uploading directory {0} to {1}".format(join(dir_path, f), construct_s3_path(bucket_name, s3_folder_name)))
            s3_dir_name = folder_name + "/" + f
            upload_dir_to_s3(join(dir_path, f), bucket_name, s3_dir_name, uuid, client)

    return s3_folder_name


def upload_file_to_s3(file_path, bucket_name, folder_name, client):
    invalid_extension = [".c", ".cpp", ".js", ".java", ".exe", ".dll", ".o"]

    if os.path.exists(file_path):
        filename = os.path.basename(file_path)
        name, extension = os.path.splitext(filename)
        if extension not in invalid_extension:
            s3_file_name = "{0}/{1}".format(folder_name, filename)
            print("uploading file {0} to {1}".format(file_path, construct_s3_path(bucket_name, s3_file_name)))
            client.upload_file(file_path, bucket_name, s3_file_name)
            return s3_file_name
    else:
        raise ValueError("file {0} does not exist".format(file_path))

def download_files_from_s3(bucket_name, code_location, dest_dir, client):
    bucket = client.list_objects_v2(Bucket=bucket_name, Prefix=code_location)
    assert bucket is not None
    for f in bucket["Contents"]:
        if os.path.basename(f["Key"]) != '':
            client.download_file(bucket_name, f["Key"],
                                 join(dest_dir, os.path.basename(f["Key"])))

def construct_s3_path(bucket_name, folder_name):
    return "s3://{0}/{1}".format(bucket_name, folder_name)
